import { FlatGitignoreOptions } from 'eslint-config-flat-gitignore';
import { ParserOptions } from '@typescript-eslint/parser';
import * as parser from '@typescript-eslint/parser';
export { parser as parserTs };
import { Linter, ESLint } from 'eslint';
import { LanguageOptions, LinterOptions } from 'eslint-define-config';
export { default as pluginAntfu } from 'eslint-plugin-antfu';
export { default as pluginComments } from 'eslint-plugin-eslint-comments';
import * as eslintPluginI from 'eslint-plugin-i';
export { eslintPluginI as pluginImport };
export { default as pluginJsdoc } from 'eslint-plugin-jsdoc';
import * as eslintPluginJsonc from 'eslint-plugin-jsonc';
export { eslintPluginJsonc as pluginJsonc };
export { default as pluginMarkdown } from 'eslint-plugin-markdown';
export { default as pluginNode } from 'eslint-plugin-n';
export { default as pluginStylistic } from '@stylistic/eslint-plugin';
export { default as pluginTs } from '@typescript-eslint/eslint-plugin';
export { default as pluginUnicorn } from 'eslint-plugin-unicorn';
export { default as pluginUnusedImports } from 'eslint-plugin-unused-imports';
import * as eslintPluginYml from 'eslint-plugin-yml';
export { eslintPluginYml as pluginYaml };
export { default as pluginNoOnlyTests } from 'eslint-plugin-no-only-tests';
export { default as pluginVitest } from 'eslint-plugin-vitest';
export { default as pluginVue } from 'eslint-plugin-vue';
export { default as pluginReact } from 'eslint-plugin-react';
export { default as pluginReactHooks } from 'eslint-plugin-react-hooks';
export { default as pluginAstro } from 'eslint-plugin-astro';
export { default as parserVue } from 'vue-eslint-parser';
export { default as parserYaml } from 'yaml-eslint-parser';
export { default as parserJsonc } from 'jsonc-eslint-parser';
export { default as parserAstro } from 'astro-eslint-parser';

/**
 * Flat ESLint Configuration.
 *
 * @see [Configuration Files (New)](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new)
 */
interface FlatESLintConfigItem {
    /**
     * The name of the configuration object.
     */
    name?: string;
    /**
     * An array of glob patterns indicating the files that the configuration object should apply to. If not specified, the configuration object applies to all files.
     *
     * @see [Ignore Patterns](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#excluding-files-with-ignores)
     */
    files?: string[];
    /**
     * An array of glob patterns indicating the files that the configuration object should not apply to. If not specified, the configuration object applies to all files matched by files.
     *
     * @see [Ignore Patterns](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#excluding-files-with-ignores)
     */
    ignores?: string[];
    /**
     * An object containing settings related to how JavaScript is configured for linting.
     *
     * @see [Configuring language options](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#configuring-language-options)
     */
    languageOptions?: LanguageOptions;
    /**
     * An object containing settings related to the linting process.
     */
    linterOptions?: LinterOptions;
    /**
     * Either an object containing `preprocess()` and `postprocess()` methods or a string indicating the name of a processor inside of a plugin (i.e., `"pluginName/processorName"`).
     *
     * @see [Using processors](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#using-processors)
     */
    processor?: string | Linter.Processor;
    /**
     * An object containing a name-value mapping of plugin names to plugin objects. When `files` is specified, these plugins are only available to the matching files.
     *
     * @see [Using plugins in your configuration](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#using-plugins-in-your-configuration)
     */
    plugins?: Record<string, ESLint.Plugin>;
    /**
     * An object containing the configured rules. When `files` or `ignores` are specified, these rule configurations are only available to the matching files.
     *
     * @see [Configuring rules](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#configuring-rules)
     */
    rules?: Record<string, Linter.RuleLevel | Linter.RuleLevelAndOptions>;
    /**
     * An object containing name-value pairs of information that should be available to all rules.
     *
     * @see [Configuring shared settings](https://eslint.org/docs/latest/user-guide/configuring/configuration-files-new#configuring-shared-settings)
     */
    settings?: Record<string, any>;
}
interface OptionsComponentExts {
    /**
     * Additional extensions for components.
     *
     * @example ['vue']
     * @default []
     */
    componentExts?: string[];
}
interface OptionsTypeScriptParserOptions {
    /**
     * Additional parser options for TypeScript.
     */
    parserOptions?: Partial<ParserOptions>;
}
interface OptionsTypeScriptWithTypes {
    /**
     * When this options is provided, type aware rules will be enabled.
     * @see https://typescript-eslint.io/linting/typed-linting/
     */
    tsconfigPath?: string;
}
interface OptionsHasTypeScript {
    typescript?: boolean;
}
interface OptionsStylistic {
    stylistic?: boolean | StylisticConfig;
}
interface StylisticConfig {
    indent?: number | 'tab';
    quotes?: 'single' | 'double';
}
interface OptionsOverrides {
    overrides?: FlatESLintConfigItem['rules'];
}
interface OptionsIsInEditor {
    isInEditor?: boolean;
}
interface OptionsConfig extends OptionsComponentExts {
    /**
     * Enable gitignore support.
     *
     * Passing an object to configure the options.
     *
     * @see https://github.com/antfu/eslint-config-flat-gitignore
     * @default true
     */
    gitignore?: boolean | FlatGitignoreOptions;
    /**
     * Enable TypeScript support.
     *
     * Passing an object to enable TypeScript Language Server support.
     *
     * @default auto-detect based on the dependencies
     */
    typescript?: boolean | OptionsTypeScriptWithTypes;
    /**
     * Enable test support.
     *
     * @default true
     */
    test?: boolean;
    /**
     * Enable Vue support.
     *
     * @default auto-detect based on the dependencies
     */
    vue?: boolean;
    /**
     * Enable React support.
     *
     * @default auto-detect based on the dependencies
     */
    react?: boolean;
    /**
     * Enable Astro support.
     *
     * @default auto-detect based on the dependencies
     */
    astro?: boolean;
    /**
     * Enable JSONC support.
     *
     * @default true
     */
    jsonc?: boolean;
    /**
     * Enable YAML support.
     *
     * @default true
     */
    yaml?: boolean;
    /**
     * Enable Markdown support.
     *
     * @default true
     */
    markdown?: boolean;
    /**
     * Enable stylistic rules.
     *
     * @default true
     */
    stylistic?: boolean | StylisticConfig;
    /**
     * Control to disable some rules in editors.
     * @default auto-detect based on the process.env
     */
    isInEditor?: boolean;
    /**
     * Provide overrides for rules for each integration.
     */
    overrides?: {
        javascript?: FlatESLintConfigItem['rules'];
        typescript?: FlatESLintConfigItem['rules'];
        test?: FlatESLintConfigItem['rules'];
        vue?: FlatESLintConfigItem['rules'];
        react?: FlatESLintConfigItem['rules'];
        astro?: FlatESLintConfigItem['rules'];
        jsonc?: FlatESLintConfigItem['rules'];
        markdown?: FlatESLintConfigItem['rules'];
        yaml?: FlatESLintConfigItem['rules'];
    };
}

/**
 * Construct an array of ESLint flat config items.
 */
declare function coderwyd(options?: OptionsConfig & FlatESLintConfigItem, ...userConfigs: (FlatESLintConfigItem | FlatESLintConfigItem[])[]): FlatESLintConfigItem[];

declare function comments(): FlatESLintConfigItem[];

declare function ignores(): FlatESLintConfigItem[];

declare function imports(options?: OptionsStylistic): FlatESLintConfigItem[];

declare function javascript(options?: OptionsIsInEditor & OptionsOverrides): FlatESLintConfigItem[];

declare function jsdoc(options?: OptionsStylistic): FlatESLintConfigItem[];

declare function jsonc(options?: OptionsStylistic & OptionsOverrides): FlatESLintConfigItem[];

declare function markdown(options?: OptionsComponentExts & OptionsOverrides): FlatESLintConfigItem[];

declare function node(): FlatESLintConfigItem[];

/**
 * Sort package.json
 *
 * Requires `jsonc` config
 */
declare function sortPackageJson(): FlatESLintConfigItem[];
/**
 * Sort tsconfig.json
 *
 * Requires `jsonc` config
 */
declare function sortTsconfig(): FlatESLintConfigItem[];

declare function stylistic(options?: StylisticConfig): FlatESLintConfigItem[];

declare function typescript(options?: OptionsComponentExts & OptionsOverrides & OptionsTypeScriptWithTypes & OptionsTypeScriptParserOptions): FlatESLintConfigItem[];

declare function unicorn(): FlatESLintConfigItem[];

declare function getVueVersion(): number;
declare function vue(options?: OptionsHasTypeScript & OptionsOverrides & OptionsStylistic): FlatESLintConfigItem[];

declare function yaml(options?: OptionsOverrides & OptionsStylistic): FlatESLintConfigItem[];

declare function test(options?: OptionsIsInEditor & OptionsOverrides): FlatESLintConfigItem[];

declare function react(options?: OptionsHasTypeScript & OptionsOverrides & OptionsStylistic): FlatESLintConfigItem[];

declare function astro(options?: OptionsHasTypeScript & OptionsOverrides): FlatESLintConfigItem[];

/**
 * Combine array and non-array configs into a single array.
 */
declare function combine(...configs: (FlatESLintConfigItem | FlatESLintConfigItem[])[]): FlatESLintConfigItem[];
declare function renameRules(rules: Record<string, any>, from: string, to: string): {
    [k: string]: any;
};

declare const GLOB_SRC_EXT = "?([cm])[jt]s?(x)";
declare const GLOB_SRC = "**/*.?([cm])[jt]s?(x)";
declare const GLOB_JS = "**/*.?([cm])js";
declare const GLOB_JSX = "**/*.?([cm])jsx";
declare const GLOB_TS = "**/*.?([cm])ts";
declare const GLOB_TSX = "**/*.?([cm])tsx";
declare const GLOB_STYLE = "**/*.{c,le,sc}ss";
declare const GLOB_CSS = "**/*.css";
declare const GLOB_LESS = "**/*.less";
declare const GLOB_SCSS = "**/*.scss";
declare const GLOB_JSON = "**/*.json";
declare const GLOB_JSON5 = "**/*.json5";
declare const GLOB_JSONC = "**/*.jsonc";
declare const GLOB_MARKDOWN = "**/*.md";
declare const GLOB_VUE = "**/*.vue";
declare const GLOB_YAML = "**/*.y?(a)ml";
declare const GLOB_HTML = "**/*.htm?(l)";
declare const GLOB_ASTRO = "**/*.astro";
declare const GLOB_MARKDOWN_CODE = "**/*.md/**/*.?([cm])[jt]s?(x)";
declare const GLOB_TESTS: string[];
declare const GLOB_ALL_SRC: string[];
declare const GLOB_EXCLUDE: string[];

export { FlatESLintConfigItem, GLOB_ALL_SRC, GLOB_ASTRO, GLOB_CSS, GLOB_EXCLUDE, GLOB_HTML, GLOB_JS, GLOB_JSON, GLOB_JSON5, GLOB_JSONC, GLOB_JSX, GLOB_LESS, GLOB_MARKDOWN, GLOB_MARKDOWN_CODE, GLOB_SCSS, GLOB_SRC, GLOB_SRC_EXT, GLOB_STYLE, GLOB_TESTS, GLOB_TS, GLOB_TSX, GLOB_VUE, GLOB_YAML, OptionsComponentExts, OptionsConfig, OptionsHasTypeScript, OptionsIsInEditor, OptionsOverrides, OptionsStylistic, OptionsTypeScriptParserOptions, OptionsTypeScriptWithTypes, StylisticConfig, astro, coderwyd, combine, comments, coderwyd as default, getVueVersion, ignores, imports, javascript, jsdoc, jsonc, markdown, node, react, renameRules, sortPackageJson, sortTsconfig, stylistic, test, typescript, unicorn, vue, yaml };
