// src/factory.ts
import process3 from "process";
import fs from "fs";
import { isPackageExists } from "local-pkg";
import gitignore from "eslint-config-flat-gitignore";

// src/plugins.ts
import { default as default2 } from "eslint-plugin-antfu";
import { default as default3 } from "eslint-plugin-eslint-comments";
import * as pluginImport from "eslint-plugin-i";
import { default as default4 } from "eslint-plugin-jsdoc";
import * as pluginJsonc from "eslint-plugin-jsonc";
import { default as default5 } from "eslint-plugin-markdown";
import { default as default6 } from "eslint-plugin-n";
import { default as default7 } from "@stylistic/eslint-plugin";
import { default as default8 } from "@typescript-eslint/eslint-plugin";
import { default as default9 } from "eslint-plugin-unicorn";
import { default as default10 } from "eslint-plugin-unused-imports";
import * as pluginYaml from "eslint-plugin-yml";
import { default as default11 } from "eslint-plugin-no-only-tests";
import { default as default12 } from "eslint-plugin-vitest";
import { default as default13 } from "eslint-plugin-vue";
import { default as default14 } from "eslint-plugin-react";
import { default as default15 } from "eslint-plugin-react-hooks";
import { default as default16 } from "eslint-plugin-astro";
import * as parserTs from "@typescript-eslint/parser";
import { default as default17 } from "vue-eslint-parser";
import { default as default18 } from "yaml-eslint-parser";
import { default as default19 } from "jsonc-eslint-parser";
import { default as default20 } from "astro-eslint-parser";

// src/configs/comments.ts
function comments() {
  return [
    {
      name: "coderwyd:eslint-comments",
      plugins: {
        "eslint-comments": default3
      },
      rules: {
        "eslint-comments/no-aggregating-enable": "error",
        "eslint-comments/no-duplicate-disable": "error",
        "eslint-comments/no-unlimited-disable": "error",
        "eslint-comments/no-unused-enable": "error"
      }
    }
  ];
}

// src/globs.ts
var GLOB_SRC_EXT = "?([cm])[jt]s?(x)";
var GLOB_SRC = "**/*.?([cm])[jt]s?(x)";
var GLOB_JS = "**/*.?([cm])js";
var GLOB_JSX = "**/*.?([cm])jsx";
var GLOB_TS = "**/*.?([cm])ts";
var GLOB_TSX = "**/*.?([cm])tsx";
var GLOB_STYLE = "**/*.{c,le,sc}ss";
var GLOB_CSS = "**/*.css";
var GLOB_LESS = "**/*.less";
var GLOB_SCSS = "**/*.scss";
var GLOB_JSON = "**/*.json";
var GLOB_JSON5 = "**/*.json5";
var GLOB_JSONC = "**/*.jsonc";
var GLOB_MARKDOWN = "**/*.md";
var GLOB_VUE = "**/*.vue";
var GLOB_YAML = "**/*.y?(a)ml";
var GLOB_HTML = "**/*.htm?(l)";
var GLOB_ASTRO = "**/*.astro";
var GLOB_MARKDOWN_CODE = `${GLOB_MARKDOWN}/${GLOB_SRC}`;
var GLOB_TESTS = [
  `**/__tests__/**/*.${GLOB_SRC_EXT}`,
  `**/*.spec.${GLOB_SRC_EXT}`,
  `**/*.test.${GLOB_SRC_EXT}`,
  `**/*.bench.${GLOB_SRC_EXT}`,
  `**/*.benchmark.${GLOB_SRC_EXT}`
];
var GLOB_ALL_SRC = [
  GLOB_SRC,
  GLOB_STYLE,
  GLOB_JSON,
  GLOB_JSON5,
  GLOB_MARKDOWN,
  GLOB_VUE,
  GLOB_YAML,
  GLOB_HTML
];
var GLOB_EXCLUDE = [
  "**/node_modules",
  "**/dist",
  "**/package-lock.json",
  "**/yarn.lock",
  "**/pnpm-lock.yaml",
  "**/bun.lockb",
  "**/output",
  "**/coverage",
  "**/temp",
  "**/.vitepress/cache",
  "**/.nuxt",
  "**/.vercel",
  "**/.changeset",
  "**/.idea",
  "**/.cache",
  "**/.output",
  "**/.vite-inspect",
  "**/CHANGELOG*.md",
  "**/*.min.*",
  "**/LICENSE*",
  "**/__snapshots__",
  "**/auto-import?(s).d.ts",
  "**/components.d.ts"
];

// src/configs/ignores.ts
function ignores() {
  return [
    {
      ignores: GLOB_EXCLUDE
    }
  ];
}

// src/configs/imports.ts
function imports(options = {}) {
  const {
    stylistic: stylistic2 = true
  } = options;
  return [
    {
      name: "coderwyd:imports",
      plugins: {
        antfu: default2,
        import: pluginImport
      },
      rules: {
        "antfu/import-dedupe": "error",
        "antfu/no-import-node-modules-by-path": "error",
        "import/first": "error",
        "import/no-duplicates": "error",
        "import/no-mutable-exports": "error",
        "import/no-named-default": "error",
        "import/no-self-import": "error",
        "import/no-webpack-loader-syntax": "error",
        "import/order": "error",
        ...stylistic2 ? {
          "import/newline-after-import": ["error", { considerComments: true, count: 1 }]
        } : {}
      }
    }
  ];
}

// src/configs/javascript.ts
import globals from "globals";

// src/flags.ts
var OFF = 0;

// src/configs/javascript.ts
function javascript(options = {}) {
  const {
    isInEditor = false,
    overrides = {}
  } = options;
  return [
    {
      languageOptions: {
        ecmaVersion: 2022,
        globals: {
          ...globals.browser,
          ...globals.es2021,
          ...globals.node,
          document: "readonly",
          navigator: "readonly",
          window: "readonly"
        },
        parserOptions: {
          ecmaFeatures: {
            jsx: true
          },
          ecmaVersion: 2022,
          sourceType: "module"
        },
        sourceType: "module"
      },
      name: "coderwyd:javascript",
      plugins: {
        "antfu": default2,
        "unused-imports": default10
      },
      rules: {
        "accessor-pairs": ["error", { enforceForClassMembers: true, setWithoutGet: true }],
        "array-callback-return": "error",
        "arrow-parens": ["error", "as-needed", { requireForBlockBody: true }],
        "block-scoped-var": "error",
        "constructor-super": "error",
        "default-case-last": "error",
        "dot-notation": ["error", { allowKeywords: true }],
        "eqeqeq": ["error", "smart"],
        "new-cap": ["error", { capIsNew: false, newIsCap: true, properties: true }],
        "no-alert": "error",
        "no-array-constructor": "error",
        "no-async-promise-executor": "error",
        "no-caller": "error",
        "no-case-declarations": "error",
        "no-class-assign": "error",
        "no-compare-neg-zero": "error",
        "no-cond-assign": ["error", "always"],
        "no-console": ["error", { allow: ["warn", "error"] }],
        "no-const-assign": "error",
        "no-control-regex": "error",
        "no-debugger": "error",
        "no-delete-var": "error",
        "no-dupe-args": "error",
        "no-dupe-class-members": "error",
        "no-dupe-keys": "error",
        "no-duplicate-case": "error",
        "no-empty": ["error", { allowEmptyCatch: true }],
        "no-empty-character-class": "error",
        "no-empty-pattern": "error",
        "no-eval": "error",
        "no-ex-assign": "error",
        "no-extend-native": "error",
        "no-extra-bind": "error",
        "no-extra-boolean-cast": "error",
        "no-fallthrough": "error",
        "no-func-assign": "error",
        "no-global-assign": "error",
        "no-implied-eval": "error",
        "no-import-assign": "error",
        "no-invalid-regexp": "error",
        "no-invalid-this": "error",
        "no-irregular-whitespace": "error",
        "no-iterator": "error",
        "no-labels": ["error", { allowLoop: false, allowSwitch: false }],
        "no-lone-blocks": "error",
        "no-loss-of-precision": "error",
        "no-misleading-character-class": "error",
        "no-multi-str": "error",
        "no-new": "error",
        "no-new-func": "error",
        "no-new-object": "error",
        "no-new-symbol": "error",
        "no-new-wrappers": "error",
        "no-obj-calls": "error",
        "no-octal": "error",
        "no-octal-escape": "error",
        "no-proto": "error",
        "no-prototype-builtins": "error",
        "no-redeclare": ["error", { builtinGlobals: false }],
        "no-regex-spaces": "error",
        "no-restricted-globals": [
          "error",
          { message: "Use `globalThis` instead.", name: "global" },
          { message: "Use `globalThis` instead.", name: "self" }
        ],
        "no-restricted-properties": [
          "error",
          { message: "Use `Object.getPrototypeOf` or `Object.setPrototypeOf` instead.", property: "__proto__" },
          { message: "Use `Object.defineProperty` instead.", property: "__defineGetter__" },
          { message: "Use `Object.defineProperty` instead.", property: "__defineSetter__" },
          { message: "Use `Object.getOwnPropertyDescriptor` instead.", property: "__lookupGetter__" },
          { message: "Use `Object.getOwnPropertyDescriptor` instead.", property: "__lookupSetter__" }
        ],
        "no-restricted-syntax": [
          "error",
          "DebuggerStatement",
          "LabeledStatement",
          "WithStatement",
          "TSEnumDeclaration[const=true]",
          "TSExportAssignment"
        ],
        "no-self-assign": ["error", { props: true }],
        "no-self-compare": "error",
        "no-sequences": "error",
        "no-shadow-restricted-names": "error",
        "no-sparse-arrays": "error",
        "no-template-curly-in-string": "error",
        "no-this-before-super": "error",
        "no-throw-literal": "error",
        "no-undef": "error",
        "no-undef-init": "error",
        "no-unexpected-multiline": "error",
        "no-unmodified-loop-condition": "error",
        "no-unneeded-ternary": ["error", { defaultAssignment: false }],
        "no-unreachable": "error",
        "no-unreachable-loop": "error",
        "no-unsafe-finally": "error",
        "no-unsafe-negation": "error",
        "no-unused-expressions": ["error", {
          allowShortCircuit: true,
          allowTaggedTemplates: true,
          allowTernary: true
        }],
        "no-unused-vars": ["error", {
          args: "none",
          caughtErrors: "none",
          ignoreRestSiblings: true,
          vars: "all"
        }],
        "no-use-before-define": ["error", { classes: false, functions: false, variables: true }],
        "no-useless-backreference": "error",
        "no-useless-call": "error",
        "no-useless-catch": "error",
        "no-useless-computed-key": "error",
        "no-useless-constructor": "error",
        "no-useless-rename": "error",
        "no-useless-return": "error",
        "no-var": "error",
        "no-void": "error",
        "no-with": "error",
        "object-shorthand": [
          "error",
          "always",
          {
            avoidQuotes: true,
            ignoreConstructors: false
          }
        ],
        "one-var": ["error", { initialized: "never" }],
        "prefer-arrow-callback": [
          "error",
          {
            allowNamedFunctions: false,
            allowUnboundThis: true
          }
        ],
        "prefer-const": [
          "error",
          {
            destructuring: "all",
            ignoreReadBeforeAssign: true
          }
        ],
        "prefer-exponentiation-operator": "error",
        "prefer-promise-reject-errors": "error",
        "prefer-regex-literals": ["error", { disallowRedundantWrapping: true }],
        "prefer-rest-params": "error",
        "prefer-spread": "error",
        "prefer-template": "error",
        "sort-imports": [
          "error",
          {
            allowSeparatedGroups: false,
            ignoreCase: false,
            ignoreDeclarationSort: true,
            ignoreMemberSort: false,
            memberSyntaxSortOrder: ["none", "all", "multiple", "single"]
          }
        ],
        "symbol-description": "error",
        "unicode-bom": ["error", "never"],
        "unused-imports/no-unused-imports": isInEditor ? OFF : "error",
        "unused-imports/no-unused-vars": [
          "error",
          { args: "after-used", argsIgnorePattern: "^_", vars: "all", varsIgnorePattern: "^_" }
        ],
        "use-isnan": ["error", { enforceForIndexOf: true, enforceForSwitchCase: true }],
        "valid-typeof": ["error", { requireStringLiterals: true }],
        "vars-on-top": "error",
        "yoda": ["error", "never"],
        ...overrides
      }
    },
    {
      files: [`scripts/${GLOB_SRC}`, `cli.${GLOB_SRC_EXT}`],
      name: "coderwyd:scripts-overrides",
      rules: {
        "no-console": OFF
      }
    }
  ];
}

// src/configs/jsdoc.ts
function jsdoc(options = {}) {
  const {
    stylistic: stylistic2 = true
  } = options;
  return [
    {
      name: "coderwyd:jsdoc",
      plugins: {
        jsdoc: default4
      },
      rules: {
        "jsdoc/check-access": "warn",
        "jsdoc/check-param-names": "warn",
        "jsdoc/check-property-names": "warn",
        "jsdoc/check-types": "warn",
        "jsdoc/empty-tags": "warn",
        "jsdoc/implements-on-classes": "warn",
        "jsdoc/no-defaults": "warn",
        "jsdoc/no-multi-asterisks": "warn",
        "jsdoc/require-param-name": "warn",
        "jsdoc/require-property": "warn",
        "jsdoc/require-property-description": "warn",
        "jsdoc/require-property-name": "warn",
        "jsdoc/require-returns-check": "warn",
        "jsdoc/require-returns-description": "warn",
        "jsdoc/require-yields-check": "warn",
        ...stylistic2 ? {
          "jsdoc/check-alignment": "warn",
          "jsdoc/multiline-blocks": "warn"
        } : {}
      }
    }
  ];
}

// src/configs/jsonc.ts
function jsonc(options = {}) {
  const {
    stylistic: stylistic2 = true,
    overrides = {}
  } = options;
  const {
    indent = 2
  } = typeof stylistic2 === "boolean" ? {} : stylistic2;
  return [
    {
      name: "coderwyd:jsonc:setup",
      plugins: {
        jsonc: pluginJsonc
      }
    },
    {
      files: [GLOB_JSON, GLOB_JSON5, GLOB_JSONC],
      languageOptions: {
        parser: default19
      },
      name: "coderwyd:jsonc:rules",
      rules: {
        "jsonc/no-bigint-literals": "error",
        "jsonc/no-binary-expression": "error",
        "jsonc/no-binary-numeric-literals": "error",
        "jsonc/no-dupe-keys": "error",
        "jsonc/no-escape-sequence-in-identifier": "error",
        "jsonc/no-floating-decimal": "error",
        "jsonc/no-hexadecimal-numeric-literals": "error",
        "jsonc/no-infinity": "error",
        "jsonc/no-multi-str": "error",
        "jsonc/no-nan": "error",
        "jsonc/no-number-props": "error",
        "jsonc/no-numeric-separators": "error",
        "jsonc/no-octal": "error",
        "jsonc/no-octal-escape": "error",
        "jsonc/no-octal-numeric-literals": "error",
        "jsonc/no-parenthesized": "error",
        "jsonc/no-plus-sign": "error",
        "jsonc/no-regexp-literals": "error",
        "jsonc/no-sparse-arrays": "error",
        "jsonc/no-template-literals": "error",
        "jsonc/no-undefined-value": "error",
        "jsonc/no-unicode-codepoint-escapes": "error",
        "jsonc/no-useless-escape": "error",
        "jsonc/space-unary-ops": "error",
        "jsonc/valid-json-number": "error",
        "jsonc/vue-custom-block/no-parsing-error": "error",
        ...stylistic2 ? {
          "jsonc/array-bracket-spacing": ["error", "never"],
          "jsonc/comma-dangle": ["error", "never"],
          "jsonc/comma-style": ["error", "last"],
          "jsonc/indent": ["error", indent],
          "jsonc/key-spacing": ["error", { afterColon: true, beforeColon: false }],
          "jsonc/object-curly-newline": ["error", { consistent: true, multiline: true }],
          "jsonc/object-curly-spacing": ["error", "always"],
          "jsonc/object-property-newline": ["error", { allowMultiplePropertiesPerLine: true }],
          "jsonc/quote-props": "error",
          "jsonc/quotes": "error"
        } : {},
        ...overrides
      }
    }
  ];
}

// src/configs/markdown.ts
function markdown(options = {}) {
  const {
    componentExts = [],
    overrides = {}
  } = options;
  return [
    {
      name: "coderwyd:markdown:setup",
      plugins: {
        markdown: default5
      }
    },
    {
      files: [GLOB_MARKDOWN],
      name: "coderwyd:markdown:processor",
      processor: "markdown/markdown"
    },
    {
      files: [
        GLOB_MARKDOWN_CODE,
        ...componentExts.map((ext) => `${GLOB_MARKDOWN}/**/*.${ext}`)
      ],
      languageOptions: {
        parserOptions: {
          ecmaFeatures: {
            impliedStrict: true
          }
        }
      },
      name: "coderwyd:markdown:rules",
      rules: {
        "antfu/no-cjs-exports": OFF,
        "antfu/no-ts-export-equal": OFF,
        "no-alert": OFF,
        "no-console": OFF,
        "no-undef": OFF,
        "no-unused-expressions": OFF,
        "no-unused-vars": OFF,
        "node/prefer-global/process": OFF,
        "style/comma-dangle": OFF,
        "style/eol-last": OFF,
        "ts/consistent-type-imports": OFF,
        "ts/no-namespace": OFF,
        "ts/no-redeclare": OFF,
        "ts/no-require-imports": OFF,
        "ts/no-unused-vars": OFF,
        "ts/no-use-before-define": OFF,
        "ts/no-var-requires": OFF,
        "unicode-bom": "off",
        "unused-imports/no-unused-imports": OFF,
        "unused-imports/no-unused-vars": OFF,
        // Type aware rules
        ...{
          "ts/await-thenable": OFF,
          "ts/dot-notation": OFF,
          "ts/no-floating-promises": OFF,
          "ts/no-for-in-array": OFF,
          "ts/no-implied-eval": OFF,
          "ts/no-misused-promises": OFF,
          "ts/no-throw-literal": OFF,
          "ts/no-unnecessary-type-assertion": OFF,
          "ts/no-unsafe-argument": OFF,
          "ts/no-unsafe-assignment": OFF,
          "ts/no-unsafe-call": OFF,
          "ts/no-unsafe-member-access": OFF,
          "ts/no-unsafe-return": OFF,
          "ts/restrict-plus-operands": OFF,
          "ts/restrict-template-expressions": OFF,
          "ts/unbound-method": OFF
        },
        ...overrides
      }
    }
  ];
}

// src/configs/node.ts
function node() {
  return [
    {
      name: "coderwyd:node",
      plugins: {
        node: default6
      },
      rules: {
        "node/handle-callback-err": ["error", "^(err|error)$"],
        "node/no-deprecated-api": "error",
        "node/no-exports-assign": "error",
        "node/no-new-require": "error",
        "node/no-path-concat": "error",
        "node/prefer-global/buffer": ["error", "never"],
        "node/prefer-global/process": ["error", "never"],
        "node/process-exit-as-throw": "error"
      }
    }
  ];
}

// src/configs/sort.ts
function sortPackageJson() {
  return [
    {
      files: ["**/package.json"],
      name: "coderwyd:sort-package-json",
      rules: {
        "jsonc/sort-array-values": [
          "error",
          {
            order: { type: "asc" },
            pathPattern: "^files$"
          }
        ],
        "jsonc/sort-keys": [
          "error",
          {
            order: [
              "publisher",
              "name",
              "displayName",
              "type",
              "version",
              "private",
              "packageManager",
              "description",
              "author",
              "license",
              "funding",
              "homepage",
              "repository",
              "bugs",
              "keywords",
              "categories",
              "sideEffects",
              "exports",
              "main",
              "module",
              "unpkg",
              "jsdelivr",
              "types",
              "typesVersions",
              "bin",
              "icon",
              "files",
              "engines",
              "activationEvents",
              "contributes",
              "scripts",
              "peerDependencies",
              "peerDependenciesMeta",
              "dependencies",
              "optionalDependencies",
              "devDependencies",
              "pnpm",
              "overrides",
              "resolutions",
              "husky",
              "simple-git-hooks",
              "lint-staged",
              "nano-staged",
              "eslintConfig"
            ],
            pathPattern: "^$"
          },
          {
            order: { type: "asc" },
            pathPattern: "^(?:dev|peer|optional|bundled)?[Dd]ependencies$"
          },
          {
            order: { type: "asc" },
            pathPattern: "^resolutions$"
          },
          {
            order: { type: "asc" },
            pathPattern: "^pnpm.overrides$"
          },
          {
            order: [
              "types",
              "import",
              "require",
              "default"
            ],
            pathPattern: "^exports.*$"
          }
        ]
      }
    }
  ];
}
function sortTsconfig() {
  return [
    {
      files: ["**/tsconfig.json", "**/tsconfig.*.json"],
      name: "coderwyd:sort-tsconfig",
      rules: {
        "jsonc/sort-keys": [
          "error",
          {
            order: [
              "extends",
              "compilerOptions",
              "references",
              "files",
              "include",
              "exclude"
            ],
            pathPattern: "^$"
          },
          {
            order: [
              /* Projects */
              "incremental",
              "composite",
              "tsBuildInfoFile",
              "disableSourceOfProjectReferenceRedirect",
              "disableSolutionSearching",
              "disableReferencedProjectLoad",
              /* Language and Environment */
              "target",
              "jsx",
              "jsxFactory",
              "jsxFragmentFactory",
              "jsxImportSource",
              "lib",
              "moduleDetection",
              "noLib",
              "reactNamespace",
              "useDefineForClassFields",
              "emitDecoratorMetadata",
              "experimentalDecorators",
              /* Modules */
              "baseUrl",
              "rootDir",
              "rootDirs",
              "customConditions",
              "module",
              "moduleResolution",
              "moduleSuffixes",
              "noResolve",
              "paths",
              "resolveJsonModule",
              "resolvePackageJsonExports",
              "resolvePackageJsonImports",
              "typeRoots",
              "types",
              "allowArbitraryExtensions",
              "allowImportingTsExtensions",
              "allowUmdGlobalAccess",
              /* JavaScript Support */
              "allowJs",
              "checkJs",
              "maxNodeModuleJsDepth",
              /* Type Checking */
              "strict",
              "strictBindCallApply",
              "strictFunctionTypes",
              "strictNullChecks",
              "strictPropertyInitialization",
              "allowUnreachableCode",
              "allowUnusedLabels",
              "alwaysStrict",
              "exactOptionalPropertyTypes",
              "noFallthroughCasesInSwitch",
              "noImplicitAny",
              "noImplicitOverride",
              "noImplicitReturns",
              "noImplicitThis",
              "noPropertyAccessFromIndexSignature",
              "noUncheckedIndexedAccess",
              "noUnusedLocals",
              "noUnusedParameters",
              "useUnknownInCatchVariables",
              /* Emit */
              "declaration",
              "declarationDir",
              "declarationMap",
              "downlevelIteration",
              "emitBOM",
              "emitDeclarationOnly",
              "importHelpers",
              "importsNotUsedAsValues",
              "inlineSourceMap",
              "inlineSources",
              "mapRoot",
              "newLine",
              "noEmit",
              "noEmitHelpers",
              "noEmitOnError",
              "outDir",
              "outFile",
              "preserveConstEnums",
              "preserveValueImports",
              "removeComments",
              "sourceMap",
              "sourceRoot",
              "stripInternal",
              /* Interop Constraints */
              "allowSyntheticDefaultImports",
              "esModuleInterop",
              "forceConsistentCasingInFileNames",
              "isolatedModules",
              "preserveSymlinks",
              "verbatimModuleSyntax",
              /* Completeness */
              "skipDefaultLibCheck",
              "skipLibCheck"
            ],
            pathPattern: "^compilerOptions$"
          }
        ]
      }
    }
  ];
}

// src/configs/stylistic.ts
function stylistic(options = {}) {
  const {
    indent = 2,
    quotes = "single"
  } = options;
  return [
    {
      name: "coderwyd:stylistic",
      plugins: {
        antfu: default2,
        style: default7
      },
      rules: {
        "antfu/consistent-list-newline": "error",
        "antfu/if-newline": "error",
        "antfu/top-level-function": "error",
        "curly": ["error", "multi-or-nest", "consistent"],
        "style/array-bracket-spacing": ["error", "never"],
        "style/arrow-spacing": ["error", { after: true, before: true }],
        "style/block-spacing": ["error", "always"],
        "style/brace-style": ["error", "stroustrup", { allowSingleLine: true }],
        "style/comma-dangle": ["error", "always-multiline"],
        "style/comma-spacing": ["error", { after: true, before: false }],
        "style/comma-style": ["error", "last"],
        "style/computed-property-spacing": ["error", "never", { enforceForClassMembers: true }],
        "style/dot-location": ["error", "property"],
        "style/eol-last": "error",
        "style/indent": ["error", indent, {
          ArrayExpression: 1,
          CallExpression: { arguments: 1 },
          FunctionDeclaration: { body: 1, parameters: 1 },
          FunctionExpression: { body: 1, parameters: 1 },
          ImportDeclaration: 1,
          MemberExpression: 1,
          ObjectExpression: 1,
          SwitchCase: 1,
          VariableDeclarator: 1,
          flatTernaryExpressions: false,
          ignoreComments: false,
          ignoredNodes: [
            "TemplateLiteral *",
            "JSXElement",
            "JSXElement > *",
            "JSXAttribute",
            "JSXIdentifier",
            "JSXNamespacedName",
            "JSXMemberExpression",
            "JSXSpreadAttribute",
            "JSXExpressionContainer",
            "JSXOpeningElement",
            "JSXClosingElement",
            "JSXFragment",
            "JSXOpeningFragment",
            "JSXClosingFragment",
            "JSXText",
            "JSXEmptyExpression",
            "JSXSpreadChild",
            "TSTypeParameterInstantiation",
            "FunctionExpression > .params[decorators.length > 0]",
            "FunctionExpression > .params > :matches(Decorator, :not(:first-child))",
            "ClassBody.body > PropertyDefinition[decorators.length > 0] > .key"
          ],
          offsetTernaryExpressions: true,
          outerIIFEBody: 1
        }],
        "style/jsx-quotes": "error",
        "style/key-spacing": ["error", { afterColon: true, beforeColon: false }],
        "style/keyword-spacing": ["error", { after: true, before: true }],
        "style/lines-between-class-members": ["error", "always", { exceptAfterSingleLine: true }],
        "style/max-statements-per-line": ["error", { max: 1 }],
        "style/member-delimiter-style": ["error", { multiline: { delimiter: "none" } }],
        "style/multiline-ternary": ["error", "always-multiline"],
        "style/new-parens": "error",
        "style/no-extra-parens": ["error", "functions"],
        "style/no-floating-decimal": "error",
        "style/no-mixed-operators": ["error", {
          allowSamePrecedence: true,
          groups: [
            ["==", "!=", "===", "!==", ">", ">=", "<", "<="],
            ["&&", "||"],
            ["in", "instanceof"]
          ]
        }],
        "style/no-mixed-spaces-and-tabs": "error",
        "style/no-multi-spaces": "error",
        "style/no-multiple-empty-lines": ["error", { max: 1, maxBOF: 0, maxEOF: 0 }],
        "style/no-tabs": indent === "tab" ? "off" : "error",
        "style/no-trailing-spaces": "error",
        "style/no-whitespace-before-property": "error",
        "style/object-curly-spacing": ["error", "always"],
        "style/object-property-newline": ["error", { allowMultiplePropertiesPerLine: true }],
        "style/operator-linebreak": ["error", "before"],
        "style/padded-blocks": ["error", { blocks: "never", classes: "never", switches: "never" }],
        "style/quote-props": ["error", "consistent-as-needed"],
        "style/quotes": ["error", quotes, { allowTemplateLiterals: true, avoidEscape: false }],
        "style/rest-spread-spacing": ["error", "never"],
        "style/semi": ["error", "never"],
        "style/semi-spacing": ["error", { after: true, before: false }],
        "style/space-before-blocks": ["error", "always"],
        "style/space-before-function-paren": ["error", { anonymous: "always", asyncArrow: "always", named: "never" }],
        "style/space-in-parens": ["error", "never"],
        "style/space-infix-ops": "error",
        "style/space-unary-ops": ["error", { nonwords: false, words: true }],
        "style/spaced-comment": ["error", "always", {
          block: {
            balanced: true,
            exceptions: ["*"],
            markers: ["!"]
          },
          line: {
            exceptions: ["/", "#"],
            markers: ["/"]
          }
        }],
        "style/template-curly-spacing": "error",
        "style/template-tag-spacing": ["error", "never"],
        "style/type-annotation-spacing": ["error", {}],
        "style/wrap-iife": ["error", "any", { functionPrototypeMethods: true }],
        "style/yield-star-spacing": ["error", "both"]
      }
    }
  ];
}

// src/configs/typescript.ts
import process from "process";

// src/utils.ts
function combine(...configs) {
  return configs.flatMap((config) => Array.isArray(config) ? config : [config]);
}
function renameRules(rules, from, to) {
  return Object.fromEntries(
    Object.entries(rules).map(([key, value]) => {
      if (key.startsWith(from))
        return [to + key.slice(from.length), value];
      return [key, value];
    })
  );
}

// src/configs/typescript.ts
function typescript(options) {
  const {
    componentExts = [],
    overrides = {},
    parserOptions = {},
    tsconfigPath
  } = options ?? {};
  const typeAwareRules = {
    "dot-notation": OFF,
    "no-implied-eval": OFF,
    "no-throw-literal": OFF,
    "ts/await-thenable": "error",
    "ts/ban-types": ["error", { types: { Function: false } }],
    "ts/dot-notation": ["error", { allowKeywords: true }],
    "ts/no-floating-promises": "error",
    "ts/no-for-in-array": "error",
    "ts/no-implied-eval": "error",
    "ts/no-misused-promises": "error",
    "ts/no-throw-literal": "error",
    "ts/no-unnecessary-type-assertion": "error",
    "ts/no-unsafe-argument": "error",
    "ts/no-unsafe-assignment": "error",
    "ts/no-unsafe-call": "error",
    "ts/no-unsafe-member-access": "error",
    "ts/no-unsafe-return": "error",
    "ts/restrict-plus-operands": "error",
    "ts/restrict-template-expressions": "error",
    "ts/unbound-method": "error"
  };
  return [
    {
      name: "coderwyd:typescript:setup",
      plugins: {
        antfu: default2,
        import: pluginImport,
        ts: default8
      }
    },
    {
      files: [
        GLOB_SRC,
        ...componentExts.map((ext) => `**/*.${ext}`)
      ],
      languageOptions: {
        parser: parserTs,
        parserOptions: {
          sourceType: "module",
          ...tsconfigPath ? {
            project: [tsconfigPath],
            tsconfigRootDir: process.cwd()
          } : {},
          ...parserOptions
        }
      },
      name: "coderwyd:typescript:rules",
      rules: {
        ...renameRules(
          default8.configs["eslint-recommended"].overrides[0].rules,
          "@typescript-eslint/",
          "ts/"
        ),
        ...renameRules(
          default8.configs.strict.rules,
          "@typescript-eslint/",
          "ts/"
        ),
        "antfu/generic-spacing": "error",
        "antfu/named-tuple-spacing": "error",
        "antfu/no-cjs-exports": "error",
        "no-dupe-class-members": OFF,
        "no-invalid-this": OFF,
        "no-loss-of-precision": OFF,
        "no-redeclare": OFF,
        "no-use-before-define": OFF,
        "no-useless-constructor": OFF,
        // TS
        "ts/ban-ts-comment": ["error", { "ts-ignore": "allow-with-description" }],
        "ts/consistent-type-definitions": ["error", "interface"],
        "ts/consistent-type-imports": ["error", { disallowTypeAnnotations: false, prefer: "type-imports" }],
        "ts/no-dupe-class-members": "error",
        "ts/no-dynamic-delete": OFF,
        "ts/no-explicit-any": OFF,
        "ts/no-extraneous-class": OFF,
        "ts/no-invalid-this": "error",
        "ts/no-invalid-void-type": OFF,
        "ts/no-loss-of-precision": "error",
        "ts/no-non-null-assertion": OFF,
        "ts/no-redeclare": "error",
        "ts/no-require-imports": "error",
        "ts/no-unused-vars": OFF,
        "ts/no-use-before-define": ["error", { classes: false, functions: false, variables: true }],
        "ts/no-useless-constructor": OFF,
        "ts/prefer-ts-expect-error": "error",
        "ts/triple-slash-reference": OFF,
        "ts/unified-signatures": OFF,
        ...tsconfigPath ? typeAwareRules : {},
        ...overrides
      }
    },
    {
      files: ["**/*.d.ts"],
      name: "coderwyd:typescript:dts-overrides",
      rules: {
        "eslint-comments/no-unlimited-disable": OFF,
        "import/no-duplicates": OFF,
        "no-restricted-syntax": OFF,
        "unused-imports/no-unused-vars": OFF
      }
    },
    {
      files: GLOB_TESTS,
      name: "coderwyd:typescript:tests-overrides",
      rules: {
        "no-unused-expressions": OFF
      }
    },
    {
      files: [GLOB_JS],
      name: "coderwyd:typescript:javascript-overrides",
      rules: {
        "ts/no-require-imports": OFF,
        "ts/no-var-requires": OFF
      }
    }
  ];
}

// src/configs/unicorn.ts
function unicorn() {
  return [
    {
      name: "coderwyd:unicorn",
      plugins: {
        unicorn: default9
      },
      rules: {
        // Pass error message when throwing errors
        "unicorn/error-message": "error",
        // Uppercase regex escapes
        "unicorn/escape-case": "error",
        // Array.isArray instead of instanceof
        "unicorn/no-instanceof-array": "error",
        // Ban `new Array` as `Array` constructor's params are ambiguous
        "unicorn/no-new-array": "error",
        // Prevent deprecated `new Buffer()`
        "unicorn/no-new-buffer": "error",
        // Lowercase number formatting for octal, hex, binary (0x1'error' instead of 0X1'error')
        "unicorn/number-literal-case": "error",
        // textContent instead of innerText
        "unicorn/prefer-dom-node-text-content": "error",
        // includes over indexOf when checking for existence
        "unicorn/prefer-includes": "error",
        // Prefer using the node: protocol
        "unicorn/prefer-node-protocol": "error",
        // Prefer using number properties like `Number.isNaN` rather than `isNaN`
        "unicorn/prefer-number-properties": "error",
        // String methods startsWith/endsWith instead of more complicated stuff
        "unicorn/prefer-string-starts-ends-with": "error",
        // Enforce throwing type error when throwing error while checking typeof
        "unicorn/prefer-type-error": "error",
        // Use new when throwing error
        "unicorn/throw-new-error": "error"
      }
    }
  ];
}

// src/configs/vue.ts
import process2 from "process";
import { getPackageInfoSync } from "local-pkg";
function getVueVersion() {
  const pkg = getPackageInfoSync("vue", { paths: [process2.cwd()] });
  if (pkg && typeof pkg.version === "string" && !Number.isNaN(+pkg.version[0]))
    return +pkg.version[0];
  return 3;
}
var isVue3 = getVueVersion() === 3;
var vue3Rules = {
  ...default13.configs.base.rules,
  ...default13.configs["vue3-essential"].rules,
  ...default13.configs["vue3-strongly-recommended"].rules,
  ...default13.configs["vue3-recommended"].rules
};
var vue2Rules = {
  ...default13.configs.base.rules,
  ...default13.configs.essential.rules,
  ...default13.configs["strongly-recommended"].rules,
  ...default13.configs.recommended.rules
};
function vue(options = {}) {
  const {
    overrides = {},
    stylistic: stylistic2 = true
  } = options;
  const {
    indent = 2
  } = typeof stylistic2 === "boolean" ? {} : stylistic2;
  return [
    {
      name: "coderwyd:vue:setup",
      plugins: {
        vue: default13
      }
    },
    {
      files: [GLOB_VUE],
      languageOptions: {
        parser: default17,
        parserOptions: {
          ecmaFeatures: {
            jsx: true
          },
          extraFileExtensions: [".vue"],
          parser: options.typescript ? parserTs : null,
          sourceType: "module"
        }
      },
      name: "coderwyd:vue:rules",
      processor: default13.processors[".vue"],
      rules: {
        ...isVue3 ? vue3Rules : vue2Rules,
        "node/prefer-global/process": OFF,
        "vue/block-order": ["error", {
          order: ["script", "template", "style"]
        }],
        "vue/component-name-in-template-casing": ["error", "PascalCase"],
        "vue/component-options-name-casing": ["error", "PascalCase"],
        "vue/custom-event-name-casing": ["error", "camelCase"],
        "vue/define-macros-order": ["error", {
          order: ["defineOptions", "defineProps", "defineEmits", "defineSlots"]
        }],
        "vue/dot-location": ["error", "property"],
        "vue/dot-notation": ["error", { allowKeywords: true }],
        "vue/eqeqeq": ["error", "smart"],
        "vue/html-indent": ["error", indent],
        "vue/html-quotes": ["error", "double"],
        "vue/max-attributes-per-line": OFF,
        "vue/multi-word-component-names": OFF,
        "vue/no-dupe-keys": OFF,
        "vue/no-empty-pattern": "error",
        "vue/no-extra-parens": ["error", "functions"],
        "vue/no-irregular-whitespace": "error",
        "vue/no-loss-of-precision": "error",
        "vue/no-restricted-syntax": [
          "error",
          "DebuggerStatement",
          "LabeledStatement",
          "WithStatement"
        ],
        "vue/no-restricted-v-bind": ["error", "/^v-/"],
        "vue/no-setup-props-reactivity-loss": OFF,
        "vue/no-sparse-arrays": "error",
        "vue/no-unused-refs": "error",
        "vue/no-useless-v-bind": "error",
        "vue/no-v-html": OFF,
        "vue/object-shorthand": [
          "error",
          "always",
          {
            avoidQuotes: true,
            ignoreConstructors: false
          }
        ],
        "vue/prefer-separate-static-class": "error",
        "vue/prefer-template": "error",
        "vue/require-default-prop": OFF,
        "vue/require-prop-types": OFF,
        "vue/space-infix-ops": "error",
        "vue/space-unary-ops": ["error", { nonwords: false, words: true }],
        ...stylistic2 ? {
          "vue/array-bracket-spacing": ["error", "never"],
          "vue/arrow-spacing": ["error", { after: true, before: true }],
          "vue/block-spacing": ["error", "always"],
          "vue/block-tag-newline": ["error", {
            multiline: "always",
            singleline: "always"
          }],
          "vue/brace-style": ["error", "stroustrup", { allowSingleLine: true }],
          "vue/comma-dangle": ["error", "always-multiline"],
          "vue/comma-spacing": ["error", { after: true, before: false }],
          "vue/comma-style": ["error", "last"],
          "vue/html-comment-content-spacing": ["error", "always", {
            exceptions: ["-"]
          }],
          "vue/key-spacing": ["error", { afterColon: true, beforeColon: false }],
          "vue/keyword-spacing": ["error", { after: true, before: true }],
          "vue/object-curly-newline": OFF,
          "vue/object-curly-spacing": ["error", "always"],
          "vue/object-property-newline": ["error", { allowMultiplePropertiesPerLine: true }],
          "vue/operator-linebreak": ["error", "before"],
          "vue/padding-line-between-blocks": ["error", "always"],
          "vue/quote-props": ["error", "consistent-as-needed"],
          "vue/space-in-parens": ["error", "never"],
          "vue/template-curly-spacing": "error"
        } : {},
        ...overrides
      }
    }
  ];
}

// src/configs/yaml.ts
function yaml(options = {}) {
  const {
    overrides = {},
    stylistic: stylistic2 = true
  } = options;
  const {
    indent = 2,
    quotes = "single"
  } = typeof stylistic2 === "boolean" ? {} : stylistic2;
  return [
    {
      name: "coderwyd:yaml:setup",
      plugins: {
        yaml: pluginYaml
      }
    },
    {
      files: [GLOB_YAML],
      languageOptions: {
        parser: default18
      },
      name: "coderwyd:yaml:rules",
      rules: {
        "style/spaced-comment": OFF,
        "yaml/block-mapping": "error",
        "yaml/block-sequence": "error",
        "yaml/no-empty-key": "error",
        "yaml/no-empty-sequence-entry": "error",
        "yaml/no-irregular-whitespace": "error",
        "yaml/plain-scalar": "error",
        "yaml/vue-custom-block/no-parsing-error": "error",
        ...stylistic2 ? {
          "yaml/block-mapping-question-indicator-newline": "error",
          "yaml/block-sequence-hyphen-indicator-newline": "error",
          "yaml/flow-mapping-curly-newline": "error",
          "yaml/flow-mapping-curly-spacing": "error",
          "yaml/flow-sequence-bracket-newline": "error",
          "yaml/flow-sequence-bracket-spacing": "error",
          "yaml/indent": ["error", indent === "tab" ? 2 : indent],
          "yaml/key-spacing": "error",
          "yaml/no-tab-indent": "error",
          "yaml/quotes": ["error", { avoidEscape: false, prefer: quotes }],
          "yaml/spaced-comment": "error"
        } : {},
        ...overrides
      }
    }
  ];
}

// src/configs/test.ts
function test(options = {}) {
  const {
    isInEditor = false,
    overrides = {}
  } = options;
  return [
    {
      name: "coderwyd:test:setup",
      plugins: {
        test: {
          ...default12,
          rules: {
            ...default12.rules,
            // extend `test/no-only-tests` rule
            ...default11.rules
          }
        }
      }
    },
    {
      files: GLOB_TESTS,
      name: "coderwyd:test:rules",
      rules: {
        "test/consistent-test-it": ["error", { fn: "it", withinDescribe: "it" }],
        "test/no-identical-title": "error",
        "test/no-only-tests": isInEditor ? OFF : "error",
        "test/prefer-hooks-in-order": "error",
        "test/prefer-lowercase-title": "error",
        ...overrides
      }
    }
  ];
}

// src/configs/react.ts
import globals2 from "globals";
function react(options = {}) {
  const {
    overrides = {},
    stylistic: stylistic2 = true
  } = options;
  const {
    indent = 2
  } = typeof stylistic2 === "boolean" ? {} : stylistic2;
  const extensions = [GLOB_JSX, ...[options.typescript ? GLOB_TSX : ""]];
  return [
    {
      name: "coderwyd:react:setup",
      plugins: {
        "react": default14,
        "react-hooks": default15
      },
      settings: {
        "import/extensions": extensions,
        "import/resolver": {
          node: { extensions }
        },
        "react": {
          version: "detect"
        }
      }
    },
    {
      files: [GLOB_JSX, ...[options.typescript ? GLOB_TSX : ""]],
      languageOptions: {
        globals: globals2.browser,
        parserOptions: {
          ecmaFeatures: {
            jsx: true
          },
          // for @typescript/eslint-parser
          jsxPragma: void 0,
          // FIXME: @typescript-eslint v6 throws deprecation warnings
          // See https://github.com/jsx-eslint/eslint-plugin-react/issues/3602
          // Remove this when they support typescript 5.2
          suppressDeprecatedPropertyWarnings: true
        }
      },
      name: "coderwyd:react:rules",
      rules: {
        ...default14.configs.recommended.rules,
        ...default15.configs.recommended.rules,
        "node/prefer-global/process": OFF,
        "react/display-name": ["off", { ignoreTranspilerName: false }],
        "react/iframe-missing-sandbox": "warn",
        "react/jsx-curly-brace-presence": ["error", { children: "never", props: "never" }],
        "react/no-unknown-property": ["error", {
          ignore: [
            // SVG
            "clip-path",
            "clip-rule",
            "fill-opacity",
            "fill-rule",
            "stroke-dasharray",
            "stroke-dashoffset",
            "stroke-linecap",
            "stroke-linejoin",
            "stroke-miterlimit",
            "stroke-opacity",
            "stroke-width"
          ]
        }],
        "react/no-unused-class-component-methods": "error",
        "react/no-unused-state": "error",
        "react/prop-types": "off",
        "react/react-in-jsx-scope": "off",
        ...stylistic2 ? {
          "react/jsx-boolean-value": ["error", "never", { always: [] }],
          "react/jsx-closing-bracket-location": ["error", "tag-aligned"],
          "react/jsx-curly-newline": ["error", {
            multiline: "consistent",
            singleline: "consistent"
          }],
          "react/jsx-curly-spacing": ["error", "never", { allowMultiline: true }],
          "react/jsx-first-prop-new-line": ["error", "multiline-multiprop"],
          "react/jsx-fragments": ["error", "syntax"],
          "react/jsx-indent": ["error", indent, { checkAttributes: false, indentLogicalExpressions: true }],
          "react/jsx-indent-props": ["error", indent],
          "react/jsx-max-props-per-line": ["error", { maximum: 1, when: "multiline" }],
          "react/jsx-no-useless-fragment": "error",
          "react/jsx-props-no-multi-spaces": "error",
          "react/jsx-tag-spacing": ["error", {
            afterOpening: "never",
            beforeClosing: "never",
            beforeSelfClosing: "always",
            closingSlash: "never"
          }],
          "react/jsx-wrap-multilines": ["error", {
            arrow: "parens-new-line",
            assignment: "parens-new-line",
            condition: "parens-new-line",
            declaration: "parens-new-line",
            logical: "parens-new-line",
            prop: "parens-new-line",
            return: "parens-new-line"
          }],
          "react/sort-comp": ["error", {
            groups: {
              lifecycle: [
                "displayName",
                "propTypes",
                "contextTypes",
                "childContextTypes",
                "mixins",
                "statics",
                "defaultProps",
                "constructor",
                "getDefaultProps",
                "getInitialState",
                "state",
                "getChildContext",
                "getDerivedStateFromProps",
                "componentWillMount",
                "UNSAFE_componentWillMount",
                "componentDidMount",
                "componentWillReceiveProps",
                "UNSAFE_componentWillReceiveProps",
                "shouldComponentUpdate",
                "componentWillUpdate",
                "UNSAFE_componentWillUpdate",
                "getSnapshotBeforeUpdate",
                "componentDidUpdate",
                "componentDidCatch",
                "componentWillUnmount"
              ],
              rendering: [
                "/^render.+$/",
                "render"
              ]
            },
            order: [
              "static-variables",
              "static-methods",
              "instance-variables",
              "lifecycle",
              "/^handle.+$/",
              "/^on.+$/",
              "getters",
              "setters",
              "/^(get|set)(?!(InitialState$|DefaultProps$|ChildContext$)).+$/",
              "instance-methods",
              "everything-else",
              "rendering"
            ]
          }],
          "react/style-prop-object": "error",
          "style/indent": ["error", indent, {
            SwitchCase: 1,
            VariableDeclarator: 1,
            // from: https://github.com/airbnb/javascript/blob/master/packages/eslint-config-airbnb-base/rules/style.js
            ignoredNodes: [
              "JSXElement",
              "JSXElement :not(JSXExpressionContainer, JSXExpressionContainer *)",
              "JSXAttribute",
              "JSXIdentifier",
              "JSXNamespacedName",
              "JSXMemberExpression",
              "JSXSpreadAttribute",
              "JSXOpeningElement",
              "JSXClosingElement",
              "JSXFragment",
              "JSXOpeningFragment",
              "JSXClosingFragment",
              "JSXText",
              "JSXEmptyExpression",
              "JSXSpreadChild"
            ],
            offsetTernaryExpressions: true,
            outerIIFEBody: 1
          }],
          "style/jsx-quotes": ["error", "prefer-double"]
        } : {},
        ...overrides
      }
    }
  ];
}

// src/configs/astro.ts
function astro(options = {}) {
  const { overrides = {} } = options;
  return [
    {
      files: [GLOB_ASTRO],
      languageOptions: {
        parser: default20,
        parserOptions: {
          extraFileExtensions: [".astro"],
          parser: options.typescript ? parserTs : null
        }
      },
      name: "coderwyd:astro",
      plugins: {
        astro: default16
      },
      rules: {
        ...default16.configs.recommended.rules,
        ...overrides
      }
    }
  ];
}

// src/factory.ts
var flatConfigProps = [
  "files",
  "ignores",
  "languageOptions",
  "linterOptions",
  "processor",
  "plugins",
  "rules",
  "settings"
];
var VuePackages = [
  "vue",
  "nuxt",
  "vitepress",
  "@slidev/cli"
];
var ReactPackages = [
  "react",
  "next"
];
var AstroPackages = [
  "astro"
];
function coderwyd(options = {}, ...userConfigs) {
  const {
    isInEditor = !!((process3.env.VSCODE_PID || process3.env.JETBRAINS_IDE) && !process3.env.CI),
    vue: enableVue = VuePackages.some((i) => isPackageExists(i)),
    react: enableReact = ReactPackages.some((i) => isPackageExists(i)),
    astro: enableAstro = AstroPackages.some((i) => isPackageExists(i)),
    typescript: enableTypeScript = isPackageExists("typescript"),
    stylistic: enableStylistic = true,
    gitignore: enableGitignore = true,
    overrides = {},
    componentExts = []
  } = options;
  const configs = [];
  if (enableGitignore) {
    if (typeof enableGitignore !== "boolean") {
      configs.push([gitignore(enableGitignore)]);
    } else {
      if (fs.existsSync(".gitignore"))
        configs.push([gitignore()]);
    }
  }
  configs.push(
    ignores(),
    javascript({ isInEditor }),
    comments(),
    node(),
    jsdoc({
      stylistic: enableStylistic
    }),
    imports({
      stylistic: enableStylistic
    }),
    unicorn()
  );
  if (enableVue)
    componentExts.push("vue");
  if (enableTypeScript) {
    configs.push(typescript({
      ...typeof enableTypeScript !== "boolean" ? enableTypeScript : {},
      componentExts,
      overrides: overrides.typescript
    }));
  }
  if (enableStylistic) {
    configs.push(stylistic(
      typeof enableStylistic === "boolean" ? {} : enableStylistic
    ));
  }
  if (options.test ?? true)
    configs.push(test({ isInEditor, overrides: overrides.test }));
  if (enableVue) {
    configs.push(vue({
      overrides: overrides.vue,
      stylistic: enableStylistic,
      typescript: !!enableTypeScript
    }));
  }
  if (enableReact) {
    configs.push(react({
      overrides: overrides.react,
      typescript: !!enableTypeScript
    }));
  }
  if (enableAstro) {
    configs.push(astro({
      overrides: overrides.astro,
      typescript: !!enableTypeScript
    }));
  }
  if (options.jsonc ?? true) {
    configs.push(
      jsonc(),
      sortPackageJson(),
      sortTsconfig()
    );
  }
  if (options.yaml ?? true) {
    configs.push(yaml({
      overrides: overrides.yaml,
      stylistic: enableStylistic
    }));
  }
  if (options.markdown ?? true)
    configs.push(markdown({ componentExts, overrides: overrides.markdown }));
  const fusedConfig = flatConfigProps.reduce((acc, key) => {
    if (key in options)
      acc[key] = options[key];
    return acc;
  }, {});
  if (Object.keys(fusedConfig).length)
    configs.push([fusedConfig]);
  const merged = combine(
    ...configs,
    ...userConfigs
  );
  return merged;
}

// src/index.ts
var src_default = coderwyd;
export {
  GLOB_ALL_SRC,
  GLOB_ASTRO,
  GLOB_CSS,
  GLOB_EXCLUDE,
  GLOB_HTML,
  GLOB_JS,
  GLOB_JSON,
  GLOB_JSON5,
  GLOB_JSONC,
  GLOB_JSX,
  GLOB_LESS,
  GLOB_MARKDOWN,
  GLOB_MARKDOWN_CODE,
  GLOB_SCSS,
  GLOB_SRC,
  GLOB_SRC_EXT,
  GLOB_STYLE,
  GLOB_TESTS,
  GLOB_TS,
  GLOB_TSX,
  GLOB_VUE,
  GLOB_YAML,
  astro,
  coderwyd,
  combine,
  comments,
  src_default as default,
  getVueVersion,
  ignores,
  imports,
  javascript,
  jsdoc,
  jsonc,
  markdown,
  node,
  default20 as parserAstro,
  default19 as parserJsonc,
  parserTs,
  default17 as parserVue,
  default18 as parserYaml,
  default2 as pluginAntfu,
  default16 as pluginAstro,
  default3 as pluginComments,
  pluginImport,
  default4 as pluginJsdoc,
  pluginJsonc,
  default5 as pluginMarkdown,
  default11 as pluginNoOnlyTests,
  default6 as pluginNode,
  default14 as pluginReact,
  default15 as pluginReactHooks,
  default7 as pluginStylistic,
  default8 as pluginTs,
  default9 as pluginUnicorn,
  default10 as pluginUnusedImports,
  default12 as pluginVitest,
  default13 as pluginVue,
  pluginYaml,
  react,
  renameRules,
  sortPackageJson,
  sortTsconfig,
  stylistic,
  test,
  typescript,
  unicorn,
  vue,
  yaml
};
